@@ -4,7 +4,7 @@ import os
 import logging
 import requests
 import pandas as pd
-from IPython.display import HTML
+from IPython.display import display, HTML
 
 logger = logging.getLogger(__name__)
 
@@ -84,8 +84,9 @@ class AthenaClient:
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
-                    response_as_df = pd.DataFrame.from_dict(response[RESULT])
-                    return HTML(response_as_df.to_html(index=False))
+                    response_as_df = pd.DataFrame.from_dict(response[RESULT]).style.set_caption("Databases").hide_index()
+                    # return HTML(response_as_df.to_html(index=False))
+                    return display(response_as_df)
                 else:
                     return response[RESULT]
             else:
@@ -109,8 +110,9 @@ class AthenaClient:
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
-                    response_as_df = pd.DataFrame.from_dict(response[RESULT])
-                    return HTML(response_as_df.to_html(index=False))
+                    response_as_df = pd.DataFrame.from_dict(response[RESULT]).style.set_caption(f'Tables in schema: {schema_name}').hide_index()
+                    # return HTML(response_as_df.to_html(index=False))
+                    return display(response_as_df)
                 else:
                     return response[RESULT]
             else:
@@ -135,9 +137,12 @@ class AthenaClient:
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
-                    results = [pd.DataFrame.from_dict(i).to_html(index=False) for i in response[RESULT]]
-                    combined_results = ''.join(results)
-                    return HTML(combined_results)
+                    # results = [pd.DataFrame.from_dict(i).to_html(index=False) for i in response[RESULT]]
+                    # combined_results = ''.join(results)
+                    table_header = f'Top {limit} records of table {schema_name}.{table_name}' if limit else f'Top 100 records of table {schema_name}.{table_name}'
+                    response_as_df = pd.DataFrame.from_dict(response[RESULT]).style.set_caption(
+                        table_header).hide_index()
+                    return display(response_as_df)
                 else:
                     return response[RESULT]
             else:
@@ -162,9 +167,11 @@ class AthenaClient:
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
-                    results = [pd.DataFrame.from_dict(i).to_html(index=False) for i in response[RESULT]]
-                    combined_results = ''.join(results)
-                    return HTML(combined_results)
+                    queries = query_string.split(';')
+                    results = [pd.DataFrame.from_dict(item).style.set_caption(f"""Query results for \"{queries[i]};\"""").hide_index() for i, item in enumerate(response[RESULT])]
+                    # combined_results = ''.join(results)
+                    # return HTML(combined_results)
+                    display(*results)
                 else:
                     return response[RESULT]
             else:
